%
%  Revive PCC
%
%  This script attempts to save and restore the current status of
%  PCC between sessions. Hence you can exit PCC, do something else,
%  and when you start PCC again, you'll be where you left off last
%  time.
%
%  Usage: put `Load "revive.q"' in your autoexec/gameinit script. The
%  rest is automatic. By default, this will also load the saved status
%  when the turn number changed.  If you don't want it to do that,
%  do `Revive.LoadOldTurn := False' after the load instruction.
%
%  History:
%  + 22/Aug/2001  basic infrastructure
%  + 15/Dec/2001  save starchart position
%  + 08/Dec/2002  save selection
%  + 11/Dec/2002  "NewTurn"
%  + 10/Apr/2015  update for PCC2 (two-file solution, remove NewTurn hook)
%
%  Note 15/Feb/2005: the NewTurn hook is now provided by the PCC core. 
%  You do no longer need this module to use that hook. However, PCC's
%  core.q contains provisions that these two do not interfere (it
%  makes sure the hook is called only once during each load).
%

Print "[revive.q 10/Apr/2015]"
If Not System.GUI Then
  Print "Revive: not loading; not in GUI mode"
  Return
EndIf

Shared Revive.LoadOldTurn = True

Sub Revive.Save
  Local fd
  Print "Revive: saving status..."
  Try
    fd := FreeFile()
    Open MakeFileName(System.GameDirectory, "status" & My.Race$ & ".cc") For Output As #fd
    Print #fd, "%"
    Print #fd, "%  File written by `revive.q' for turn ", Turn, " (", Turn.Date, ", ", Turn.Time, ")"
    Print #fd, "%"
    Print #fd
    Print #fd, "Revive.CheckTurn '", Turn.Date, Turn.Time, "'"
    Print #fd
    Print #fd, "Chart.X := ", Chart.X
    Print #fd, "Chart.Y := ", Chart.Y
    Print #fd, "Revive.LoadSelection"
    Close #fd

    Open MakeFileName(System.GameDirectory, "status" & My.Race$ & ".sel") For Output As #fd
    SelectionSave fd
    Close #fd
  Else
    Messagebox "Could not save status.", "Error"
    Try Close fd
  EndTry
EndSub

% This is a hack. For PCC2, we need the two-file solution.
Sub Revive.LoadSelection
  Local fd := FreeFile()
  Try
    Open MakeFileName(System.GameDirectory, "status" & My.Race$ & ".sel") For Input As #fd
    SelectionLoad fd, "at"
  EndTry
  Try Close fd
EndSub

Sub Revive.Load
  % Note that this must be a multiline Try, one-line Try doesn't work
  % here in 1.1.3 and below :-(
  Try
    Load MakeFileName(System.GameDirectory, "status" & My.Race$ & ".cc")
  EndTry
EndSub

Sub Revive.CheckTurn (ts)
print "revive.checkturn"
  If ts <> Turn.Date & Turn.Time Then
    If (Not Revive.LoadOldTurn) Then
      Print "Revive: not restoring status from `", ts, "'"
      Abort "-"
    EndIf
  EndIf
  Print "Revive: restoring status..."
EndSub

On Load Do Revive.Load
On Exit Do Revive.Save
